@@ -15,7 +15,7 @@ class OOMMFRunner:
     a subclass of this class.
     """
 
-    def call(self, argstr):
+    def call(self, argstr, need_stderr=False):
         # print day and time at which we start calling OOMMF (useful
         # for longer runs)
         x = datetime.datetime.now()
@@ -25,7 +25,7 @@ class OOMMFRunner:
 
         # measure execution time of OOMMF
         tic = time.time()
-        val = self._call(argstr=argstr)
+        val = self._call(argstr=argstr, need_stderr=need_stderr)
 
         toc = time.time()
         seconds = "[{:0.1f}s]".format(toc - tic)
@@ -45,17 +45,20 @@ class OOMMFRunner:
 
         return val
 
-    def _call(self, argstr):
+    def _call(self, argstr, need_stderr=False):
         # Implement in subclass
         raise NotImplementedError
 
     def version(self, where=None):
-        p = self.call(argstr="+version")
-        return p.stderr.text.split("oommf.tcl")[-1].strip()
+        p = self.call(argstr="+version", need_stderr=True)
+        return p.stderr.decode('utf-8').split("oommf.tcl")[-1].strip()
 
     def platform(self, where=None):
-        p = self.call(argstr="+platform")
-        return p.stderr.text
+        p = self.call(argstr="+platform", need_stderr=True)
+        return p.stderr.decode('utf-8')
+
+    def kill(self, targets=('all',)):
+        raise NotImplementedError
 
 class ScriptOOMMFRunner(OOMMFRunner):
     """Run OOMMF on this system, using an oommf executable on $PATH 
@@ -66,7 +69,7 @@ class ScriptOOMMFRunner(OOMMFRunner):
     def _oommf_cmd_tuple(self):
         return (self.script_name, )
 
-    def _call(self, argstr):
+    def _call(self, argstr, need_stderr=False):
         cmd = (self.script_name, "boxsi", "+fg", argstr, "-exitondone", "1")
         return run(cmd, stdout=PIPE, stderr=PIPE)
 
@@ -82,30 +85,20 @@ class NativeOOMMFRunner(ScriptOOMMFRunner):
     def __init__(self, oommf_tcl_path):
         self.oommf_tcl_path = oommf_tcl_path
 
-    def _call(self, argstr):
+    def _call(self, argstr, need_stderr=False):
         cmd = ("tclsh", self.oommf_tcl_path, "boxsi", "+fg",
                argstr, "-exitondone", "1")
-        return run(cmd, stdout=PIPE, stderr=PIPE)
+        if sys.platform == 'win32':
+            stdout = stderr = None
+            if need_stderr:
+                stderr = PIPE
+        else:
+            stdout = stderr = PIPE
+        return run(cmd, stdout=stdout, stderr=stderr)
 
     def kill(self, targets=('all',)):
         run(("tclsh", self.oommf_tcl_path, "killoommf") + targets)
 
-class WindowsCondaOOMMFRunner(OOMMFRunner):
-    """Run OOMMF in a conda env on Windows.
-    
-    tclsh is not available, so we call oxs.exe directly.
-    """
-    def __init__(self, oommf_root):
-        self.oommf_root = oommf_root
-    
-    def _call(self, argstr):
-        oxs_exe = os.path.join(self.oommf_root, 'app', 'oxs', 'windows-x86_64', 'oxs.exe')
-        boxsi = os.path.join(self.oommf_root, 'app', 'oxs', 'boxsi.tcl')
-        return run([oxs_exe, boxsi, argstr], stdout=PIPE, stderr=PIPE)
-    
-    def kill(self, targets=('all',)):
-        pass
-
 
 class DockerOOMMFRunner(OOMMFRunner):
     """Run OOMMF inside a docker image"""
@@ -113,7 +106,7 @@ class DockerOOMMFRunner(OOMMFRunner):
         self.image = image
         self.docker_exe = docker_exe
 
-    def _call(self, argstr):
+    def _call(self, argstr, need_stderr=False):
         run([self.docker_exe, "pull", self.image])
         cmd = [self.docker_exe, 'run', '-v', os.getcwd()+':/io', self.image,
                "/bin/bash", "-c",
@@ -166,12 +159,13 @@ def get_oommf_runner(use_cache=True, docker_exe='docker', oommf_exe='oommf'):
 
     if sys.platform == 'win32' and \
             os.path.isdir(os.path.join(sys.prefix, 'conda-meta')):
-        # In a conda env on Windows
-        oommf_root = os.path.join(sys.prefix, 'opt', 'oommf')
-        if os.path.isdir(oommf_root):
-            _cached_oommf_runner = WindowsCondaOOMMFRunner(oommf_root)
+        # In a conda env on Windows, would probably also work on Mac/Linux
+        oommf_tcl = os.path.join(sys.prefix, 'opt', 'oommf', 'oommf.tcl')
+        if os.path.isfile(oommf_tcl):
+            _cached_oommf_runner = NativeOOMMFRunner(oommf_tcl)
             return _cached_oommf_runner
-               
+
+	# 'oommf' available as a command - in a conda env on Mac/Linux, or oommf installed separately
     oommf_exe_path = which(oommf_exe)
     if oommf_exe_path:
         _cached_oommf_runner = ScriptOOMMFRunner(oommf_exe_path)
